aboutsummaryrefslogtreecommitdiff
path: root/src/patch/ghost_zone.cc
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-10 12:42:14 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-10 12:42:14 +0000
commite9aaf42eedcda6b0f7dd2d6ce44b265377b928de (patch)
treede3d6e2a65eb8072b4293e14aec50015da61dd80 /src/patch/ghost_zone.cc
parent6246b68fd99f8776e9c42e474e9bcc12d6666188 (diff)
rename patch_frontier --> patch_interp everywhere
git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@475 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/patch/ghost_zone.cc')
-rw-r--r--src/patch/ghost_zone.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/patch/ghost_zone.cc b/src/patch/ghost_zone.cc
index 5b3454e..0b844ab 100644
--- a/src/patch/ghost_zone.cc
+++ b/src/patch/ghost_zone.cc
@@ -38,7 +38,7 @@ using jtutil::error_exit;
#include "patch.hh"
#include "patch_edge.hh"
#include "ghost_zone.hh"
-#include "patch_frontier.hh"
+#include "patch_interp.hh"
//******************************************************************************
//******************************************************************************
@@ -378,10 +378,10 @@ return max_par_adjacent_ghost_zone().is_symmetry()
// object. It
// - sets up the par coordinate mapping information
// - sets up the interpolator data pointer and result arrays
// - constructs the *other* patch's patch_frontier:: object
// and sets our patch frontier pointer to point to it
//
// We use our ipar as the patch_frontier's parindex.
//
void interpatch_ghost_zone::finish_setup(int interp_handle,
int interp_par_table_handle)
@@ -393,7 +393,7 @@ const int other_max_iperp = std::max(other_iperp(min_iperp()),
//
// set up arrays giving [min,max] ipar that we'll use at each other_iperp
// ... we will pass these arrays by reference to the other patch's
// patch_frontier object, with ipar being parindex there
//
min_ipar_used_ = new jtutil::array1d<int>(other_min_iperp, other_max_iperp);
max_ipar_used_ = new jtutil::array1d<int>(other_min_iperp, other_max_iperp);
@@ -454,12 +454,12 @@ interp_result_buffer_
//
// construct and link to the *other* patch's frontier
//
-other_frontier_ = new patch_frontier(other_edge(),
+other_frontier_ = new patch_interp(other_edge(),
other_min_iperp, other_max_iperp,
*min_ipar_used_, *max_ipar_used_,
*other_par_,
interp_handle, interp_par_table_handle);
-other_patch().set_patch_frontier(other_edge(), other_frontier_);
+other_patch().set_patch_interp(other_edge(), other_frontier_);
}
@@ -378,10 +378,10 @@ return max_par_adjacent_ghost_zone().is_symmetry()
// - sets up the par coordinate mapping information
// - sets up the interpolator data pointer and result arrays
-// - constructs the *other* patch's patch_frontier:: object
+// - constructs the *other* patch's patch_interp:: object
// and sets our patch frontier pointer to point to it
//
@@ -378,10 +378,10 @@ return max_par_adjacent_ghost_zone().is_symmetry()
// and sets our patch frontier pointer to point to it
//
-// We use our ipar as the patch_frontier's parindex.
+// We use our ipar as the patch_interp's parindex.
//
void interpatch_ghost_zone::finish_setup(int interp_handle,
@@ -393,7 +393,7 @@ const int other_max_iperp = std::max(other_iperp(min_iperp()),
// set up arrays giving [min,max] ipar that we'll use at each other_iperp
// ... we will pass these arrays by reference to the other patch's
-// patch_frontier object, with ipar being parindex there
+// patch_interp object, with ipar being parindex there
//
min_ipar_used_ = new jtutil::array1d<int>(other_min_iperp, other_max_iperp);